/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file zap.h
 *
 * @type helper
 *
 * @description
 *
 * The Zap helper is an interface to the Zap redraw module.
 * @note Knowledge of the Zap module is required.
 */

#ifndef __rov_zap
#define __rov_zap


#ifdef __cplusplus
extern "C"
{
#endif

/**
 * Initialises the Zap helper.
 */
void zap_init(void);

/**
 * Inform the Zap helper that the mode has changed.
 */
void zap_modechange(void);

/**
 * Redraw an area of the screen.
 * @param lines the pointer to the lines as generated by zap_prcesstext()
 * @param fore the foreground WIMP colour.
 * @param back the background WIMP colour.
 * @param c the canvas being redrawn.
 * @note This is normally called in a canvas redraw or update event handler.
 * @see zap_processtext()
 */
void zap_redraw(int *lines,
		int fore,
		int back,
		canvas c);

/**
 * Calculate line positions.
 * @param txt the pointer to the text buffer (with control codes).
 * @param lines the pointer the buffer to hold the line pointers (NULL for allocate one).
 * @return the new pointer (if it needed to be allocated).
 */
int* zap_processtext(char *txt,
		     int *lines);


#ifdef __cplusplus
}
#endif

#endif
